@@ -11,6 +11,26 @@ register("evdev", "/dev/input/by-path/platform-gpio-keys-event",
 	408, "restart_button",
 	133, "media_button")
 
+register("system-status")
+
+-- Set to "false" to suppress the sounding of the buzzer
+buzzer = true
+
+function system_status( status )
+	logprint("System status: "..status)
+	if status == "start" then
+		piccmd("statusled", "greenon")
+		piccmd("powerled", "on")
+		if buzzer then piccmd("buzzer", "short") end
+	elseif status == "stop" then
+		piccmd("statusled", "redon")
+		piccmd("powerled", "1hz")
+		if buzzer then piccmd("buzzer", "short") end
+	else
+		logprint("Unknown system status")
+	end
+end
+
 function power_button( time )
 	os.execute("poweroff")
 end
@@ -61,3 +81,5 @@ end
 function temp_high(  )
 	setfan("full")
 end
+
+confdir("/etc/qcontrol.d")
